import { Component, OnInit } from '@angular/core';
import {PlatformService} from '../../../services/platform.service';
import {FormBuilder, FormGroup} from '@angular/forms';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';

@Component({
  selector: 'app-platform-list',
  templateUrl: './platform-list.component.html',
  styleUrls: ['./platform-list.component.scss']
})
export class PlatformListComponent implements OnInit {

  sortConfigModal = false;

  dataArray = [];
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number;
  whereObject: any = {};

  platformForm: FormGroup;

  constructor(private modal: NzModalService,
              private message: NzMessageService,
              private form: FormBuilder,
              private platformService: PlatformService) { }

  ngOnInit(): void {
    this.platformForm = this.form.group({
      id: [null],
      platformName: [null],
      sort: [null],
    });
    this.requestData();
  }

  /**
   * 请求数据
   */
  requestData() {
    this.tableLoading = true;
    this.platformService.getPlatformList(data => {
      if (data['return_code'] === '000000') {
        this.dataArray = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData();
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }


  showSortConfigModal(data: object) {
    this.platformForm.patchValue(data);
    this.sortConfigModal = true;
  }

  saveSortConfig() {
    for (const i in this.platformForm.controls) {
      this.platformForm.controls[i].markAsDirty();
      this.platformForm.controls[i].updateValueAndValidity();
    }
    if (this.platformForm.status == null || this.platformForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请规范填写所有的必填项信息',
      });
      return;
    }

    this.platformService.configPlatformSort(this.platformForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '操作成功',
        });
        this.requestData();
        this.closeSortConfigModal();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }

  closeSortConfigModal() {
    this.sortConfigModal = false;
  }

}
