import { Component, OnInit } from '@angular/core';
import {SalesmanService} from '../../../services/salesman.service';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {NzModalService} from 'ng-zorro-antd';
import {ActivatedRoute, Params, Router} from '@angular/router';

@Component({
  selector: 'app-salesman-update',
  templateUrl: './salesman-update.component.html',
  styleUrls: ['./salesman-update.component.scss']
})
export class SalesmanUpdateComponent implements OnInit {

  salesmanForm: FormGroup;
  btnLoading = false;

  dataObject: any = {
    salesmanAccount : {
      loginName: ''
    }
  };

  constructor(private form: FormBuilder,
              private modal: NzModalService,
              private salesmanService: SalesmanService,
              private activatedRoute: ActivatedRoute,
              private router: Router) { }

  ngOnInit(): void {
    this.salesmanForm = this.form.group({
      salesmanId: [null, [Validators.required]],
      name: [null, [Validators.required]],
      phone: [null, [Validators.required]],
    });

    this.activatedRoute.queryParams.subscribe((queryParams: Params) => {
      if (queryParams['salesmanId'] != null && queryParams['salesmanId'].length > 0) {
        this.salesmanService.querySalesman(queryParams['salesmanId'], data => {
          if (data['return_code'] === '000000') {
            this.dataObject = data['return_data'];
            data['return_data']['salesmanDetail']['salesmanId'] = data['return_data']['salesmanDetail']['id'];
            this.salesmanForm.patchValue(data['return_data']['salesmanDetail']);
          }
        });
      }
    });

  }

  submitFrom() {
    this.btnLoading = true;
    for (const i in this.salesmanForm.controls) {
      this.salesmanForm.controls[i].markAsDirty();
      this.salesmanForm.controls[i].updateValueAndValidity();
    }
    if (this.salesmanForm.status == null || this.salesmanForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请规范填写所有的必填项信息',
      });
      return;
    }

    this.salesmanService.updateSalesman(this.salesmanForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '修改成功',
          nzOnOk: () => this.router.navigateByUrl('admin/salesman/list')
        });
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
      this.btnLoading = false;
    });
  }
}
