import { Component, OnInit } from '@angular/core';
import {StoreService} from '../../../services/store.service';
import {LocalStorageService} from '../../../services/local-storage.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {FormBuilder, FormGroup} from '@angular/forms';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {ActivatedRoute, Params} from '@angular/router';

@Component({
  selector: 'app-store-list',
  templateUrl: './store-list.component.html',
  styleUrls: ['./store-list.component.scss']
})
export class StoreListComponent implements OnInit {

  dataObject: any = {};
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number;
  whereObject: any = {};

  constructor(private store: LocalStorageService, // 数据请求
              private modal: NzModalService,
              private message: NzMessageService,
              private storeService: StoreService,
              private activatedRoute: ActivatedRoute,
              private form: FormBuilder) { }

  ngOnInit(): void {
    this.searchForm = this.form.group({
      name: [null],
      contactPerson: [null],
      contactPersonPhone: [null],
      status: [null],
    });
    this.activatedRoute.queryParams.subscribe((queryParams: Params) => {
      if (queryParams['merId'] != null && queryParams['merId'].length > 0) {
          this.whereObject['merId'] = queryParams['merId'];
        }
      this.requestData(1);
    });
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.storeService.getStoreList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 弹出删除对话框
   */
  showDisableStoreConfirm(id: number, disable: boolean): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否' + (disable ? '禁用' : '启用') + '门店',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.disableStore(id, disable)
    });
  }

  /**
   * 禁用数据
   *
   */
  disableStore(id: number, disablev: boolean) {
    this.storeService.disabledStore({ storeId : id, disable: disablev}, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

}
